@@ -40,6 +40,7 @@ END_EVENT_TABLE()
 Battle::Battle(IServer& serv, int id)
     : m_auto_unspec(false)
     , m_auto_unspec_num_players(0)
+    , m_autolaunch_game(true)
     , m_serv(serv)
     , m_ah(*this)
     , m_autolock_on_start(false)
@@ -137,6 +138,11 @@ void Battle::SetImReady(bool ready)
 	SendMyBattleStatus();
 }
 
+void Battle::SetAutolaunchGame(bool autolaunch)
+{
+	m_autolaunch_game = autolaunch;
+}
+
 void Battle::Say(const std::string& msg)
 {
 	m_serv.SayBattle(m_opts.battleid, msg);
@@ -611,15 +617,21 @@ void Battle::StartHostedBattle()
 
 void Battle::StartSpring()
 {
-	if (UserExists(GetMe().GetNick()) && !GetMe().Status().in_game) {
-		GetMe().BattleStatus().ready = false;
-		SendMyBattleStatus();
-		// set m_generating_script, this will make the script.txt writer realize we're just clients even if using a relayhost
-		m_generating_script = true;
-		GetMe().Status().in_game = spring().Run(*this);
-		m_generating_script = false;
-		GetMe().SendMyUserStatus();
-	}
+	if (!m_autolaunch_game)
+		return;
+
+	User& me = GetMe();
+	if (!UserExists(me.GetNick()))
+		return;
+	if (me.Status().in_game)
+		return;
+	me.BattleStatus().ready = false;
+	SendMyBattleStatus();
+	// set m_generating_script, this will make the script.txt writer realize we're just clients even if using a relayhost
+	m_generating_script = true;
+	me.Status().in_game = spring().Run(*this);
+	m_generating_script = false;
+	me.SendMyUserStatus();
 }
 
 void Battle::OnTimer(wxTimerEvent&)
