@@ -32,7 +32,7 @@ CRapidDownloader::~CRapidDownloader()
 	sdps.clear();
 }
 
-void CRapidDownloader::addRemoteDsp(CSdp& sdp)
+void CRapidDownloader::addRemoteSdp(CSdp& sdp)
 {
 	sdps.push_back(sdp);
 }
@@ -195,6 +195,7 @@ bool CRapidDownloader::parse()
 	}
 	gzFile fp = gzdopen(fileno(f), "rb");
 	if (fp == Z_NULL) {
+		fclose(f);
 		LOG_ERROR("Could not open %s", path.c_str());
 		return false;
 	}
