@@ -139,7 +139,10 @@ void UnitsyncLib::_Init()
 {
 	if (IsLoaded() && m_init != NULL) {
 		m_current_mod.clear();
-		m_init(true, 1);
+		const int res = m_init(true, 1);
+		if (res == 0) {
+			LslError("Unitsync init failed!");
+		}
 		const std::vector<std::string> errors = GetUnitsyncErrors();
 		for (const std::string& error : errors) {
 			LslError("%s", error.c_str());
@@ -562,6 +565,12 @@ unsigned int UnitsyncLib::GetPrimaryModChecksumFromName(const std::string& name)
 	return m_get_primary_mod_checksum_from_name(name.c_str());
 }
 
+unsigned int UnitsyncLib::GetMapChecksumFromName(const std::string& name)
+{
+	InitLib(m_get_map_checksum_from_name);
+	return m_get_map_checksum_from_name(name.c_str());
+}
+
 UnitsyncLib::StringVector UnitsyncLib::GetModDeps(int index)
 {
 	const int count = GetPrimaryModArchiveCount(index);
