@@ -13,6 +13,8 @@
 #include <stdio.h>
 #include <list>
 
+// TODO: Many of these enums are not implemented.
+// e.g. RAPID_VALIDATE_DELETE, RAPID_SEARCH, WIDGET_SEARCH...
 enum {
 	RAPID_DOWNLOAD = 0,
 	RAPID_VALIDATE,
@@ -149,6 +151,7 @@ int main(int argc, char** argv)
 		DownloadSetConfig(CONFIG_FILESYSTEM_WRITEPATH, "");
 	}
 
+	optind = 1; // reset argv scanning
 	while (true) {
 		const int c = getopt_long(argc, argv, "", long_options, nullptr);
 		if (c == -1)
@@ -194,8 +197,11 @@ int main(int argc, char** argv)
 				}
 				break;
 			}
-			case HELP:
-			default: {
+			case HTTP_SEARCH: {
+				printf("Not implemented\n");
+				break;
+			}
+			case HELP: {
 				show_help(argv[0]);
 				break;
 			}
