@@ -799,13 +799,13 @@ void ChatPanel::SetTopic(const wxString& who, const wxString& message)
 	// change the image of the tab to show new events
 	if (m_topic_set)
 		SetIconHighlight(highlight_say);
-	OutputLine(_("** Channel topic:"), col);
+	OutputLine(_T("** ") + _("Channel topic"), col);
 	wxStringTokenizer tkz(message, _T("\n"));
 	while (tkz.HasMoreTokens()) {
 		wxString msg = tkz.GetNextToken();
 		OutputLine(_T(" ") + msg, col);
 	}
-	OutputLine(_("** Set by ") + who, col);
+	OutputLine(_T("** ") + wxString::Format(_("Set by %s"), who), col);
 	m_topic_set = true;
 }
 
@@ -924,7 +924,7 @@ bool ChatPanel::Say(const wxString& message) //FIXME: remove all parsing / token
 					Say(url);
 					return true;
 				} else {
-					customMessageBoxModal(SL_MAIN_ICON, _("Failed to post to pastebin.com."));
+					customMessageBoxModal(SL_MAIN_ICON, wxString::Format(_("Failed to post to %s"), _T("paste.springfiles.com")));
 					return false;
 				}
 			}
@@ -992,7 +992,7 @@ bool ChatPanel::Say(const wxString& message) //FIXME: remove all parsing / token
 		} else if (m_type == CPT_User) {
 
 			if (m_user == 0) {
-				OutputError(_(" User is offline."));
+				OutputError(_("User is offline."));
 				return true;
 			}
 			if (line.StartsWith(_T( "/" ))) {
@@ -1030,7 +1030,7 @@ bool ChatPanel::Say(const wxString& message) //FIXME: remove all parsing / token
 			}
 
 			m_server->SendCmd(STD_STRING(line), "");
-			OutputLine(_("Sent: \"") + line + _("\""), sett().GetChatColorNormal());
+			OutputLine(_("Sent: \"") + line + _T("\""), sett().GetChatColorNormal());
 		}
 	}
 	return true;
@@ -1064,14 +1064,14 @@ void ChatPanel::OnUserDisconnected()
 {
 	// change the image of the tab to show new events
 	SetIconHighlight(highlight_join_leave);
-	OutputLine(_("** User is now offline."), sett().GetChatColorJoinPart());
+	OutputLine(_T("** ") + _("User is now offline."), sett().GetChatColorJoinPart());
 }
 
 void ChatPanel::OnUserConnected()
 {
 	// change the image of the tab to show new events
 	SetIconHighlight(highlight_join_leave);
-	OutputLine(_("** User just got online."), sett().GetChatColorJoinPart());
+	OutputLine(_T("** ") + _("User just got online."), sett().GetChatColorJoinPart());
 }
 
 
@@ -1197,7 +1197,7 @@ void ChatPanel::SetBattle(IBattle* battle)
 	}
 
 	if (m_battle != NULL) {
-		OutputLine(_("** Left Battle."), sett().GetChatColorNotification());
+		OutputLine(_T("** ") + _("Left Battle."), sett().GetChatColorNotification());
 	}
 
 	if (battle == NULL) {
@@ -1205,7 +1205,7 @@ void ChatPanel::SetBattle(IBattle* battle)
 		return;
 	}
 
-	OutputLine(_("** Joined Battle."), sett().GetChatColorNotification());
+	OutputLine(_T("** ") + _("Joined Battle."), sett().GetChatColorNotification());
 
 	for (unsigned int i = 0; i < battle->GetNumUsers(); ++i) {
 		const wxString nick = TowxString(battle->GetUser(i).GetNick());
