@@ -52,11 +52,6 @@ wxMenu* ChatPanelMenu::GetMenu()
 	if (m_chatpanel->m_type == CPT_Channel) {
 		wxLogMessage(_T( "channel" ));
 
-		m_subscribe = new wxMenuItem(m_menu_all, CHAT_MENU_CH_SUBSCRIBE, _("Subscribe to this channel"), wxEmptyString, wxITEM_CHECK);
-		m_menu_all->Append(m_subscribe);
-		m_subscribe->Check(m_chatpanel->m_channel->IsSubscribed());
-
-
 		wxMenuItem* leaveitem = new wxMenuItem(m_menu_all, CHAT_MENU_CH_LEAVE, _("Leave"), wxEmptyString, wxITEM_NORMAL);
 		m_menu_all->Append(leaveitem);
 	}
@@ -722,17 +717,6 @@ void ChatPanelMenu::OnUserMenuCreateGroup(wxCommandEvent& /*unused*/)
 	}
 }
 
-void ChatPanelMenu::OnChannelSubscribe(wxCommandEvent& /*unused*/)
-{
-	const std::string chan = m_chatpanel->m_channel->GetName();
-	IServer& serv = m_chatpanel->m_channel->GetServer();
-	if (!m_chatpanel->m_channel->IsSubscribed()) {
-		serv.SendCmd("SUBSCRIBE", "chanName=" + chan);
-	} else {
-		serv.SendCmd("UNSUBSCRIBE", "chanName=" + chan);
-	}
-}
-
 void ChatPanelMenu::OnMenuItem(wxCommandEvent& event)
 {
 	if (event.GetId() == CHAT_MENU_SHOW_MUTELIST)
@@ -839,9 +823,6 @@ void ChatPanelMenu::OnMenuItem(wxCommandEvent& event)
 		OnUserMenuDeleteFromGroup(event);
 	else if (event.GetId() == wxID_COPY)
 		m_chatpanel->m_chatlog_text->OnCopy(event);
-	else if (event.GetId() == CHAT_MENU_CH_SUBSCRIBE)
-		OnChannelSubscribe(event);
-
 	else
 		OnUserMenuAddToGroup(event);
 }
