@@ -51,7 +51,6 @@ ConnectWindow::ConnectWindow(wxWindow* parent, Ui& ui)
 	wxString password;
 	bool savepass;
 	bool autoconnect;
-	bool tls;
 
 	SetIcon(wxIcon(connect_xpm));
 
@@ -60,7 +59,6 @@ ConnectWindow::ConnectWindow(wxWindow* parent, Ui& ui)
 	password = sett().GetServerAccountPass(server);
 	savepass = sett().GetServerAccountSavePass(server);
 	autoconnect = cfg().ReadBool(_T( "/Server/Autoconnect" ));
-	tls = sett().IsServerTLS(STD_STRING(server));
 
 	// Create all UI elements.
 	m_tabs = new wxNotebook(this, -1);
@@ -81,12 +79,8 @@ ConnectWindow::ConnectWindow(wxWindow* parent, Ui& ui)
 	m_autoconnect_check = new wxCheckBox(m_login_tab, -1, _("Autoconnect next time"));
 	m_autoconnect_check->SetToolTip(_("remember connection details and automatically connect to server on next lobby startup"));
 
-	m_tls_check = new wxCheckBox(m_login_tab, -1, _("TLS"));
-	m_tls_check->SetToolTip(_("Use encrypted connection to connect to the Lobby server"));
-
 	m_rpass_check->SetValue(savepass);
 	m_autoconnect_check->SetValue(autoconnect);
-	m_tls_check->SetValue(tls);
 
 	m_acc_note_line = new wxStaticLine(m_login_tab);
 
@@ -118,7 +112,6 @@ ConnectWindow::ConnectWindow(wxWindow* parent, Ui& ui)
 
 	m_rpass_sizer->Add(m_rpass_check, 2, wxEXPAND | wxALL | wxALIGN_RIGHT, 4);
 	m_rpass_sizer->Add(m_autoconnect_check, 2, wxEXPAND | wxALL | wxALIGN_RIGHT, 4);
-	m_rpass_sizer->Add(m_tls_check, 2, wxEXPAND | wxALL | wxALIGN_RIGHT, 4);
 
 	m_pass_sizer->Add(m_pass_lbl, 1, wxALL | wxALIGN_CENTER_VERTICAL, 4);
 	m_pass_sizer->Add(m_pass_text, 2, wxEXPAND | wxALL, 4);
@@ -267,7 +260,6 @@ void ConnectWindow::OnOk(wxCommandEvent&)
 	}
 	sett().SetDefaultServer(HostAddress);
 	cfg().Write(_T( "/Server/Autoconnect" ), m_autoconnect_check->IsChecked());
-	sett().SetServerTLS(STD_STRING(HostAddress), m_tls_check->IsChecked());
 
 	//if autoconnect enabled force saving of pw, actual saving is done in Ui::DoConnect
 
