@@ -63,7 +63,7 @@
 
 SLCONFIG("/General/AutoUpdate", true, "Determines if springlobby should check for updates on startup");
 SLCONFIG("/General/LastUpdateCheck", 0L, "Last time springlobby checked for an update");
-SLCONFIG("/GUI/StartTab", (long)MainWindow::PAGE_SINGLE, "which tab to show on startup");
+SLCONFIG("/GUI/StartTab", (long)MainWindow::PAGE_BATTLELIST, "which tab to show on startup");
 SLCONFIG("/Chat/BroadcastEverywhere", true, "setting to spam the server messages in all channels");
 SLCONFIG("/Server/Autoconnect", false, "Connect to server on startup");
 SLCONFIG("/Server/TLS", false, "Use encrypted connection to the lobby server");
@@ -299,9 +299,6 @@ void Ui::OnConnected(IServer& server, const wxString& server_name, const wxStrin
 	std::map<std::string, LSL::SpringBundle> enginebundles = SlPaths::GetSpringVersionList();
 	if (!SlPaths::GetCompatibleVersion(STD_STRING(version)).empty())
 		return;
-	if (Ask(_("Spring can't be found"), wxString::Format(_T("No engine compatible to the lobby server default version spring %s can be found, try to download it?"), version.c_str()))) {
-		prDownloader().Download(DownloadEnum::CAT_ENGINE, "spring " + STD_STRING(version));
-	}
 }
 
 void Ui::OnLoggedIn()
@@ -568,7 +565,7 @@ void Ui::OnUserLeftBattle(IBattle& battle, User& user, bool isbot)
 			OnBattleInfoUpdated(battle, wxEmptyString);
 			if (&user == &m_serv->GetMe()) {
 				mw().GetJoinTab().LeaveCurrentBattle();
-				mw().ShowTab(MainWindow::PAGE_LIST);
+				mw().ShowTab(MainWindow::PAGE_BATTLELIST);
 			}
 		}
 	} catch (...) {
@@ -598,7 +595,7 @@ void Ui::OnJoinedBattle(IBattle& battle)
 	if (m_main_win == 0)
 		return;
 	mw().GetJoinTab().JoinBattle(battle);
-	mw().ShowTab(MainWindow::PAGE_JOIN);
+	mw().ShowTab(MainWindow::PAGE_BATTLEROOM);
 	if (battle.GetNatType() != NAT_None) {
 		wxLogWarning(_T("joining game with NAT transversal"));
 	}
@@ -610,7 +607,7 @@ void Ui::OnHostedBattle(IBattle& battle)
 	if (m_main_win == 0)
 		return;
 	mw().GetJoinTab().HostBattle(battle);
-	mw().ShowTab(MainWindow::PAGE_JOIN);
+	mw().ShowTab(MainWindow::PAGE_BATTLEROOM);
 }
 
 
@@ -819,7 +816,7 @@ void Ui::CheckForUpdates(bool show)
 		return;
 	}
 #ifdef __WXMSW__
-	const wxString message = wxString::Format(_("Your %s version is not up to date.\n\n%s\n\nWould you like to update to the new version?"),
+	const wxString message = wxString::Format(_("Your %s version is not up to date.") + _T("\n\n%s\n\n") + _("Would you like to update to the new version?"),
 						  TowxString(getSpringlobbyName()).c_str(),
 						  msg.c_str());
 	const wxString heading = _("Update Springlobby?");
@@ -829,9 +826,8 @@ void Ui::CheckForUpdates(bool show)
 		prDownloader().UpdateApplication(GetDownloadUrl(latestversion));
 	} catch (Exception& ex) {
 		//this will also happen if updater exe is not present so we don't really ne special check for existance of it
-		const wxString errormsg = wxString::Format(_("Automatic update failed\n\
-					%s\n\
-					you will be redirected to a web page with instructions and the download link will be opened in your browser. %s"),
+		const wxString errormsg = wxString::Format(_("Automatic update failed.") +_T("\n%s\n%s\n") +
+					_("you will be redirected to a web page with instructions and the download link will be opened in your browser."),
 							   ex.Reason(), msg);
 		customMessageBox(SL_MAIN_ICON, errormsg, _("Updater error."));
 		OpenWebBrowser(_T("https://github.com/springlobby/springlobby/wiki/Install#Windows_Binary"));
@@ -907,19 +903,19 @@ bool Ui::NeedsDownload(const IBattle* battle, bool uiprompt, DownloadEnum::Categ
 		return true;
 	}
 	bool needstuff = false;
-	std::vector<std::string> promptCollection;
+	std::string stodl;
 	std::list<std::pair<DownloadEnum::Category, std::string>> todl;
 
-	if (requested(cat, DownloadEnum::CAT_ENGINE) && !battle->EngineExists()) {
-		promptCollection.push_back("engine " + battle->GetEngineName() + " " + battle->GetEngineVersion());
+	if (requested(cat, DownloadEnum::CAT_ENGINE) && !battle->EngineExists() && !battle->GetEngineName().empty() && !battle->GetEngineVersion().empty()) {
+		stodl.append("- engine " + battle->GetEngineName() + " " + battle->GetEngineVersion() + "\n");
 		todl.push_back(std::make_pair(DownloadEnum::CAT_ENGINE, battle->GetEngineName() + " " + battle->GetEngineVersion()));
 	}
-	if (requested(cat, DownloadEnum::CAT_MAP) && !battle->MapExists(false)) {
-		promptCollection.push_back("map " + battle->GetHostMapName());
+	if (requested(cat, DownloadEnum::CAT_MAP) && !battle->MapExists(false) && !battle->GetHostMapName().empty()) {
+		stodl.append("- map " + battle->GetHostMapName() + "\n");
 		todl.push_back(std::make_pair(DownloadEnum::CAT_MAP, battle->GetHostMapName()));
 	}
-	if (requested(cat, DownloadEnum::CAT_GAME) && !battle->GameExists(false)) {
-		promptCollection.push_back("game " + battle->GetHostGameName());
+	if (requested(cat, DownloadEnum::CAT_GAME) && !battle->GameExists(false) && !battle->GetHostGameName().empty()) {
+		stodl.append("- game " + battle->GetHostGameName() + "\n");
 		todl.push_back(std::make_pair(DownloadEnum::CAT_GAME, battle->GetHostGameName()));
 	}
 
@@ -927,16 +923,7 @@ bool Ui::NeedsDownload(const IBattle* battle, bool uiprompt, DownloadEnum::Categ
 	if (!todl.empty()) {
 		needstuff = true;
 		if (uiprompt) {
-			std::string prompt = "The " + promptCollection[0];
-			for (size_t i = 1; i < promptCollection.size(); i++) {
-				if (i == promptCollection.size() - 1) {
-					prompt += " and ";
-				} else {
-					prompt += " ,";
-				}
-				prompt += promptCollection[i];
-			}
-			prompt += _(" is required to play. Should it be downloaded?");
+			const wxString prompt = _("Content is required to play. Should it be downloaded?") + _T("\n") + stodl;
 
 			if (!Ask(_("Content is missing"), prompt))
 				return true;
