@@ -816,17 +816,20 @@ void ServerEvents::OnRing(const std::string& from)
 
 void ServerEvents::OnServerBroadcast(const std::string& message)
 {
+	wxLogWarning("%s", message);
 	ui().OnServerBroadcast(m_serv, TowxString(message));
 }
 
 void ServerEvents::OnServerMessage(const std::string& message)
 {
+	wxLogWarning("%s", message);
 	ui().OnServerMessage(m_serv, TowxString(message));
 }
 
 
 void ServerEvents::OnServerMessageBox(const std::string& message)
 {
+	wxLogWarning("%s", message);
 	ui().ShowMessage(_("Server Message"), TowxString(message));
 }
 
@@ -927,7 +930,7 @@ void ServerEvents::AutoCheckCommandSpam(IBattle& battle, User& user)
 
 void ServerEvents::OnMutelistBegin(const std::string& channel)
 {
-	mutelistWindow(_("Begin mutelist for ") + TowxString(channel), wxString::Format(_("%s mutelist"), channel.c_str()));
+	mutelistWindow(wxString::Format(_("Begin mutelist for channel %s"), channel.c_str()), wxString::Format(_("%s mutelist"), channel.c_str()));
 }
 
 void ServerEvents::OnMutelistItem(const std::string& /*unused*/, const std::string& mutee, const std::string& description)
