@@ -33,6 +33,8 @@ lsl/networking/tasserver.cpp
 #include "utils/conversion.h"
 #include "utils/slconfig.h"
 #include "utils/version.h"
+
+#include <json/reader.h>
 #include <lslutils/misc.h>
 
 SLCONFIG("/Server/ExitMessage", "Using http://springlobby.info/", "Message which is send when leaving server");
@@ -274,7 +276,6 @@ void TASServer::Connect(const ServerLoginInfo& server)
 
 	m_serverinfo = server;
 	m_buffer.clear();
-	m_subscriptions.clear();
 	if (m_sock != NULL) {
 		Disconnect();
 	}
@@ -503,7 +504,7 @@ void TASServer::ExecuteCommand(const std::string& in)
 	}
 }
 
-
+/*
 static LSL::StringMap parseKeyValue(const std::string& str)
 {
 	const LSL::StringVector params = LSL::Util::StringTokenize(str, "\t");
@@ -518,7 +519,7 @@ static LSL::StringMap parseKeyValue(const std::string& str)
 	}
 	return result;
 }
-
+*/
 
 void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inparams, int replyid)
 {
@@ -532,7 +533,8 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 
 	if (cmd == "TASSERVER") {
 #ifdef SSL_SUPPORT
-		if (!m_sock->IsTLS() && sett().IsServerTLS(GetServerName()) ) {
+		if (!m_sock->IsTLS()) {
+			Stop(); //don't send ping until TLS handshake is complete
 			SendCmd("STLS", "");
 		} else {
 #endif
@@ -550,8 +552,9 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 		}
 #endif
 	} else if (cmd == "OK") {
-		if (!m_sock->IsTLS() && sett().IsServerTLS(GetServerName()) ) {
+		if (!m_sock->IsTLS()) {
 			m_sock->StartTLS(sett().GetServerFingerprint(GetServerName()));
+			Start(); //restart ping as server + client have startet TLS
 		}
 	} else if (cmd == "ACCEPTED") {
 		SetUsername(params);
@@ -618,7 +621,6 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 		m_online = true;
 		if (UserExists("RelayHostManagerList"))
 			SayPrivate("RelayHostManagerList", "!lm");
-		SendCmd("LISTSUBSCRIPTIONS", "");
 		m_se->OnLoginInfoComplete();
 	} else if (cmd == "REMOVEUSER") {
 		nick = GetWordParam(params);
@@ -643,15 +645,16 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 		HandlePong(replyid);
 	} else if (cmd == "JOIN") {
 		channel = GetWordParam(params);
+		int lastid = 0;
+		cfg().Read(wxString::Format("/Channels/%s/lastid", channel.c_str()), &lastid);
 		m_se->OnJoinChannelResult(true, channel, "");
-	} else if (cmd == "JOIN") {
-		channel = GetWordParam(params);
-		error = GetSentenceParam(params);
-		m_se->OnJoinChannelResult(false, channel, error);
+		SendCmd("GETCHANNELMESSAGES", stdprintf("%s %d", channel.c_str(), lastid));
 	} else if (cmd == "SAID") {
 		channel = GetWordParam(params);
 		nick = GetWordParam(params);
 		m_se->OnChannelSaid(channel, nick, params);
+	} else if (cmd == "JSON") {
+		ParseJson(inparams);
 	} else if (cmd == "JOINED") {
 		channel = GetWordParam(params);
 		nick = GetWordParam(params);
@@ -954,22 +957,43 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 		m_se->OnConnected(m_serverinfo.description, "", true, m_supported_spring_version, m_server_lanmode);
 	} else if (cmd == "REGISTRATIONDENIED") {
 		m_se->RegistrationDenied(params);
-	} else if (cmd == "LISTSUBSCRIPTION") {
-		const LSL::StringMap keyvals = parseKeyValue(GetWordParam(params));
-		const std::string keyname = "chanName";
-		if (keyvals.find(keyname) != keyvals.end()) {
-			m_subscriptions.insert(keyvals.at(keyname));
-		}
-	} else if (cmd == "STARTLISTSUBSCRIPTION") {
-		m_subscriptions.clear();
-	} else if (cmd == "ENDLISTSUBSCRIPTION") {
-		//m_se->OnSubscriptons();
 	} else {
-		wxLogWarning(wxString::Format(_T("??? Cmd: %s params: %s"), TowxString(cmd).c_str(), params.c_str()));
+		wxLogWarning(wxString::Format("??? Cmd: %s params: %s" , cmd.c_str(), params.c_str()));
 		m_se->OnUnknownCommand(cmd, params);
 	}
 }
 
+void TASServer::ParseJson(const std::string& jsonstr)
+{
+	wxLogDebug("JSON %s", jsonstr.c_str());
+
+        Json::Value js; // will contains the root value after parsing.
+        Json::Reader reader;
+        const bool parsingSuccessful = reader.parse(jsonstr, js);
+	if (!parsingSuccessful) {
+		wxLogWarning("Invalid json: %s", jsonstr.c_str());
+		return;
+	}
+
+	if (!js.isObject()) {
+		wxLogWarning("Invalid json, object excepted: %s", jsonstr.c_str());
+		return;
+	}
+
+	if (!js["SAID"].isObject()) {
+		wxLogWarning("Invalid json, object excepted: %s", jsonstr.c_str());
+		return;
+	}
+
+	Json::Value said = js["SAID"];
+	cfg().Write(wxString::Format("/Channels/%s/lastid", said["chanName"].asString()), said["id"].asInt());
+	m_se->OnChannelSaid(said["chanName"].asString(), said["userName"].asString(), said["msg"].asString());
+
+	//TODO: store last id for channel
+	//said["time"].asInt64();
+	//said["id"].asUInt64();
+}
+
 
 void TASServer::RelayCmd(const std::string& command, const std::string& param)
 {
